RSAPrivateKey class

Private keys in RSA

Inheritance
Implemented types

Constructors

RSAPrivateKey(BigInt modulus, BigInt privateExponent, BigInt? p, BigInt? q, [@Deprecated('Public exponent is calculated from the other values') BigInt? publicExponent])
Create an RSA private key for the given parameters.

Properties

d → BigInt?
Get private exponent d = e^-1
no setter
exponent → BigInt?
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
modulus → BigInt?
finalinherited
n → BigInt?
Get modulus n = p·q
no setterinherited
p → BigInt?
final
privateExponent → BigInt?
Get the private exponent (d)
no setter
pubExponent → BigInt?
Get the public exponent (e)
no setter
publicExponent → BigInt?
Get the public exponent (e)
no setter
q → BigInt?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override