RSAPublicKey class

Public keys in RSA

Inheritance
Implemented types

Constructors

RSAPublicKey(BigInt modulus, BigInt exponent)
Create an RSA public key for the given parameters.

Properties

e → BigInt?
Get public exponent e
no setter
exponent → BigInt?
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
modulus → BigInt?
finalinherited
n → BigInt?
Get modulus n = p·q
no setterinherited
publicExponent → BigInt?
Get the public exponent.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override