ASN1Object class

Base model for all ASN1Objects

Implementers

Constructors

ASN1Object({int? tag})
ASN1Object.fromBytes(Uint8List? encodedBytes)
Creates a new ASN1Object from the given encodedBytes.

Properties

dumpIndent ↔ int
getter/setter pair
encodedBytes ↔ Uint8List?
The encoded bytes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isConstructed ↔ bool?
Describes if this ASN1 Object is constructed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ int?
The BER tag representing this object.
getter/setter pair
totalEncodedByteLength → int
The total length of this object, including its value bytes, the encoded tag and length bytes.
no setter
valueByteLength ↔ int?
Length of the encoded value bytes.
getter/setter pair
valueBytes ↔ Uint8List?
The value bytes.
getter/setter pair
valueStartPosition ↔ int
The index where the value bytes start. This is the position after the tag + length bytes.
getter/setter pair

Methods

dump({int spaces = 0}) → String
Creates a readable dump from the current ASN1Object.
encode({ASN1EncodingRule encodingRule = ASN1EncodingRule.ENCODING_DER}) → Uint8List
Encode the object to their byte representation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited