ObjectIdentifiers class

Class holding a list of object identifiers

Constructors

ObjectIdentifiers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getIdentifierByIdentifier(String? identifier) → Map<String, dynamic>?
Returns the object identifier corresponding to the given identifier.
getIdentifierByName(String readableName) → Map<String, dynamic>?
Returns the object identifier corresponding to the given readableName.