ASN1Integer class

Inheritance
Implementers

Constructors

ASN1Integer(BigInt? integer, {int tag = ASN1Tags.INTEGER})
Create an ASN1Integer entity with the given BigInt integer.
ASN1Integer.fromBytes(Uint8List encodedBytes)
Creates an ASN1Integer entity from the given encodedBytes.
ASN1Integer.fromtInt(int i, {int tag = ASN1Tags.INTEGER})
Create an ASN1Integer entity with the given int i.

Properties

dumpIndent ↔ int
getter/setter pairinherited
encodedBytes ↔ Uint8List?
The encoded bytes.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
integer ↔ BigInt?
The integer value
getter/setter pair
isConstructed ↔ bool?
Describes if this ASN1 Object is constructed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ int?
The BER tag representing this object.
getter/setter pairinherited
totalEncodedByteLength → int
The total length of this object, including its value bytes, the encoded tag and length bytes.
no setterinherited
valueByteLength ↔ int?
Length of the encoded value bytes.
getter/setter pairinherited
valueBytes ↔ Uint8List?
The value bytes.
getter/setter pairinherited
valueStartPosition ↔ int
The index where the value bytes start. This is the position after the tag + length bytes.
getter/setter pairinherited

Methods

dump({int spaces = 0}) → String
Creates a readable dump from the current ASN1Object.
override
encode({ASN1EncodingRule encodingRule = ASN1EncodingRule.ENCODING_DER}) → Uint8List
Encodes this ASN1Object depending on the given encodingRule
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited