ASN1AlgorithmIdentifier class

AlgorithmIdentifier ::= SEQUENCE {
  algorithm OBJECT IDENTIFIER,
  parameters ANY DEFINED BY algorithm OPTIONAL
}
Inheritance

Constructors

ASN1AlgorithmIdentifier(ASN1ObjectIdentifier algorithm, {ASN1Object? parameters})
ASN1AlgorithmIdentifier.fromIdentifier(String identifier, {ASN1Object? parameters})
Creates a AlgorithmIdentifier instance from the given identifier like "1.3.14.3.2.26".
ASN1AlgorithmIdentifier.fromName(String name, {ASN1Object? parameters})
Creates a AlgorithmIdentifier instance from the given name like "sha1".
ASN1AlgorithmIdentifier.fromSequence(ASN1Sequence seq)

Properties

algorithm ↔ ASN1ObjectIdentifier
getter/setter pair
dumpIndent ↔ int
getter/setter pairinherited
encodedBytes ↔ Uint8List?
The encoded bytes.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isConstructed ↔ bool?
Describes if this ASN1 Object is constructed.
getter/setter pairinherited
parameters ↔ ASN1Object?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ int?
The BER tag representing this object.
getter/setter pairinherited
totalEncodedByteLength → int
The total length of this object, including its value bytes, the encoded tag and length bytes.
no setterinherited
valueByteLength ↔ int?
Length of the encoded value bytes.
getter/setter pairinherited
valueBytes ↔ Uint8List?
The value bytes.
getter/setter pairinherited
valueStartPosition ↔ int
The index where the value bytes start. This is the position after the tag + length bytes.
getter/setter pairinherited

Methods

dump({int spaces = 0}) → String
Creates a readable dump from the current ASN1Object.
inherited
encode({ASN1EncodingRule encodingRule = ASN1EncodingRule.ENCODING_DER}) → Uint8List
Encode the object to their byte representation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited