SRP6VerifierGenerator class

Generates new SRP verifier for user

Constructors

SRP6VerifierGenerator({required SRP6GroupParameters group, required Digest digest})

Properties

digest ↔ Digest
getter/setter pair
g ↔ BigInt
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
N ↔ BigInt
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateVerifier(Uint8List salt, Uint8List identity, Uint8List password) → BigInt
Creates a new SRP verifier salt The salt to use, generally should be large and random identity The user's identifying information (eg. username) password The user's password returns A new verifier for use in future SRP authentication
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited